summaryrefslogtreecommitdiff
path: root/framework/Util/TCallChain.php
diff options
context:
space:
mode:
Diffstat (limited to 'framework/Util/TCallChain.php')
-rw-r--r--framework/Util/TCallChain.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/framework/Util/TCallChain.php b/framework/Util/TCallChain.php
index 4e9e23f7..49891641 100644
--- a/framework/Util/TCallChain.php
+++ b/framework/Util/TCallChain.php
@@ -19,7 +19,7 @@
class TCallChain extends TList implements IDynamicMethods
{
/**
* @var {@link TListIterator} for moving through the chained method calls
*/
private $_iterator=null;
@@ -97,7 +97,7 @@ class TCallChain extends TList implements IDynamicMethods
if(!$this->_iterator)
{
$chain_array=array_reverse($this->toArray());
- $this->_iterator=new TListIterator($chain_array);
+ $this->_iterator=new ArrayIterator($chain_array);
}
if($this->_iterator->valid())
do {
@@ -19,7 +19,7 @@
{
/**
- * @var {@link TListIterator} for moving through the chained method calls
+ * @var {@link ArrayIterator} for moving through the chained method calls
*/
private $_iterator=null;